@@ -1,8 +1,8 @@
 """ example data description """
+from datetime import date, time
 
 from aind_data_schema import RawDataDescription
 from aind_data_schema.data_description import Funding
-from datetime import date, time
 
 d = RawDataDescription(
     modality="ecephys",
@@ -13,5 +13,4 @@ d = RawDataDescription(
     funding_source=[Funding(funder="AIND")],
 )
 
-with open("data_description.json", "w") as f:
-    f.write(d.json(indent=3))
+d.write_standard_file()
