@@ -1,12 +1,12 @@
 """ testing examples """
 
 import glob
+import importlib
+import logging
+import sys
 import unittest
 from pathlib import Path
-import importlib
-import sys
-from unittest.mock import patch, mock_open
-import logging
+from unittest.mock import mock_open, patch
 
 EXAMPLES_DIR = Path(__file__).parents[1] / "examples"
 
@@ -31,11 +31,9 @@ class ExampleTests(unittest.TestCase):
             module = importlib.util.module_from_spec(spec)
             sys.modules["test_module"] = module
 
-            with patch(
-                "test_module.open", new_callable=mock_open
-            ) as mocked_file:
+            with patch("builtins.open", new_callable=mock_open) as mocked_file:
                 spec.loader.exec_module(module)
-                h = mocked_file()
+                h = mocked_file.return_value.__enter__()
                 h.write.assert_called_once_with(target_data)
 
 
